@@ -24,8 +24,7 @@ impl<C: Cipher> Eax<C> {
         if C::BLOCK_SIZE != 16 {
             return Err(Error::InvalidArgument {
                 argument_name: "C::BLOCK_SIZE",
-            }
-            .into());
+            });
         }
 
         let mut ctx = unsafe { zeroed() };
