@@ -5,6 +5,8 @@ pub use self::aead::Aead;
 
 mod eax;
 pub use self::eax::Eax;
+mod ocb;
+pub use self::ocb::{Ocb, OCB_IS_SUPPORTED, typenum};
 mod gcm;
 pub use self::gcm::Gcm;
 mod ccm;
