@@ -2,7 +2,7 @@ use nettle_sys::{
     des3_ctx, nettle_des3_decrypt, nettle_des3_encrypt, nettle_des3_set_key,
 };
 use std::cmp::min;
-use std::mem::zeroed;
+use std::mem::{MaybeUninit, transmute};
 use std::os::raw::c_void;
 
 use crate::cipher::RawCipherFunctionPointer;
@@ -10,9 +10,11 @@ use crate::{cipher::Cipher, Error, Result};
 
 /// Triple DES in EDE configuration defined in RFC 1851.
 pub struct Des3 {
-    context: des3_ctx,
+    context: Box<des3_ctx>,
 }
 
+impl_zeroing_drop_for!(Des3);
+
 impl Des3 {
     /// Creates a new instance with `key` that can be used for both encryption and decryption.
     pub fn with_key(key: &[u8]) -> Result<Self> {
@@ -20,12 +22,13 @@ impl Des3 {
             return Err(Error::InvalidArgument { argument_name: "key" });
         }
 
-        let mut ctx = unsafe { zeroed() };
-        unsafe {
-            nettle_des3_set_key(&mut ctx as *mut _, key.as_ptr());
-        }
+        let context = unsafe {
+            let mut ctx = Box::new(MaybeUninit::uninit());
+            nettle_des3_set_key(ctx.as_mut_ptr(), key.as_ptr());
+            transmute(ctx)
+        };
 
-        Ok(Des3 { context: ctx })
+        Ok(Des3 { context })
     }
 }
 
@@ -44,7 +47,7 @@ impl Cipher for Des3 {
     fn encrypt(&mut self, dst: &mut [u8], src: &[u8]) {
         unsafe {
             nettle_des3_encrypt(
-                &mut self.context as *mut _,
+                self.context.as_mut() as *mut _,
                 min(src.len(), dst.len()),
                 dst.as_mut_ptr(),
                 src.as_ptr(),
@@ -55,7 +58,7 @@ impl Cipher for Des3 {
     fn decrypt(&mut self, dst: &mut [u8], src: &[u8]) {
         unsafe {
             nettle_des3_decrypt(
-                &mut self.context as *mut _,
+                self.context.as_mut() as *mut _,
                 min(src.len(), dst.len()),
                 dst.as_mut_ptr(),
                 src.as_ptr(),
@@ -64,7 +67,7 @@ impl Cipher for Des3 {
     }
 
     fn context(&mut self) -> *mut c_void {
-        ((&mut self.context) as *mut des3_ctx) as *mut c_void
+        (self.context.as_mut() as *mut des3_ctx) as *mut c_void
     }
 
     fn raw_encrypt_function() -> RawCipherFunctionPointer {
