@@ -3,7 +3,7 @@ use nettle_sys::{
     nettle_salsa20_set_nonce, nettle_salsa20r12_crypt, salsa20_ctx,
 };
 use std::cmp::min;
-use std::mem::zeroed;
+use std::mem::{MaybeUninit, transmute};
 
 use crate::{Error, Result};
 
@@ -12,9 +12,11 @@ use crate::{Error, Result};
 /// # Note
 /// Salsa20/12 it a reduced round version of Salsa20.
 pub struct Salsa20R12_128 {
-    context: salsa20_ctx,
+    context: Box<salsa20_ctx>,
 }
 
+impl_zeroing_drop_for!(Salsa20R12_128);
+
 impl Salsa20R12_128 {
     /// Salsa20/12 block size in bytes.
     pub const BLOCK_SIZE: usize = ::nettle_sys::SALSA20_BLOCK_SIZE as usize;
@@ -34,20 +36,21 @@ impl Salsa20R12_128 {
             return Err(Error::InvalidArgument { argument_name: "nonce" });
         }
 
-        let mut ctx = unsafe { zeroed() };
-        unsafe {
-            nettle_salsa20_128_set_key(&mut ctx as *mut _, key.as_ptr());
-            nettle_salsa20_set_nonce(&mut ctx as *mut _, nonce.as_ptr());
-        }
+        let context = unsafe {
+            let mut ctx = Box::new(MaybeUninit::uninit());
+            nettle_salsa20_128_set_key(ctx.as_mut_ptr(), key.as_ptr());
+            nettle_salsa20_set_nonce(ctx.as_mut_ptr(), nonce.as_ptr());
+            transmute(ctx)
+        };
 
-        Ok(Salsa20R12_128 { context: ctx })
+        Ok(Salsa20R12_128 { context })
     }
 
     /// Encrypt/decrypt data from `src` to `dst`.
     pub fn crypt(&mut self, dst: &mut [u8], src: &[u8]) {
         unsafe {
             nettle_salsa20r12_crypt(
-                &mut self.context as *mut _,
+                self.context.as_mut() as *mut _,
                 min(src.len(), dst.len()),
                 dst.as_mut_ptr(),
                 src.as_ptr(),
@@ -61,9 +64,11 @@ impl Salsa20R12_128 {
 /// # Note
 /// Salsa20/12 it a reduced round version of Salsa20.
 pub struct Salsa20R12_256 {
-    context: salsa20_ctx,
+    context: Box<salsa20_ctx>,
 }
 
+impl_zeroing_drop_for!(Salsa20R12_256);
+
 impl Salsa20R12_256 {
     /// Salsa20/12 block size in bytes.
     pub const BLOCK_SIZE: usize = ::nettle_sys::SALSA20_BLOCK_SIZE as usize;
@@ -83,15 +88,14 @@ impl Salsa20R12_256 {
             return Err(Error::InvalidArgument { argument_name: "nonce" });
         }
 
-        let mut ctx = unsafe { zeroed() };
-        unsafe {
-            nettle_salsa20_256_set_key(&mut ctx as *mut _, key.as_ptr());
-        }
-        unsafe {
-            nettle_salsa20_set_nonce(&mut ctx as *mut _, nonce.as_ptr());
-        }
+        let context = unsafe {
+            let mut ctx = Box::new(MaybeUninit::uninit());
+            nettle_salsa20_256_set_key(ctx.as_mut_ptr(), key.as_ptr());
+            nettle_salsa20_set_nonce(ctx.as_mut_ptr(), nonce.as_ptr());
+            transmute(ctx)
+        };
 
-        Ok(Salsa20R12_256 { context: ctx })
+        Ok(Salsa20R12_256 { context })
     }
 
     /// Encrypt/decrypt data from `src` to `dst`.
@@ -99,7 +103,7 @@ impl Salsa20R12_256 {
         assert_eq!(dst.len(), src.len());
         unsafe {
             nettle_salsa20r12_crypt(
-                &mut self.context as *mut _,
+                self.context.as_mut() as *mut _,
                 dst.len(),
                 dst.as_mut_ptr(),
                 src.as_ptr(),
