@@ -27,8 +27,8 @@ where
 
 /// Derive DH public key.
 ///
-/// Computes the public key `q` for a given secret `n`. Returns an error if `q` or `n` are not
-/// `CURVE25519_SIZE` bytes long.
+/// Computes the public key `q` for a given secret `n`. Returns an
+/// error if `q` or `n` are not [`CURVE25519_SIZE`] bytes long.
 pub fn mul_g(q: &mut [u8], n: &[u8]) -> Result<()> {
     if q.len() != CURVE25519_SIZE {
         return Err(Error::InvalidArgument { argument_name: "q" });
@@ -46,8 +46,9 @@ pub fn mul_g(q: &mut [u8], n: &[u8]) -> Result<()> {
 
 /// Derive DH shared secret.
 ///
-/// Computes the shared secret `q` for our private key `n` and the other parties public key `p`.
-/// Results an error if `q`, `n` or `p` are not `CURVE25519_SIZE` bytes long.
+/// Computes the shared secret `q` for our private key `n` and the
+/// other parties public key `p`.  Returns an error if `q`, `n`, or
+/// `p` are not [`CURVE25519_SIZE`] bytes long.
 pub fn mul(q: &mut [u8], n: &[u8], p: &[u8]) -> Result<()> {
     if q.len() != CURVE25519_SIZE {
         return Err(Error::InvalidArgument { argument_name: "q" });
@@ -78,7 +79,7 @@ mod tests {
         let bob_priv = &b"\x5d\xab\x08\x7e\x62\x4a\x8a\x4b\x79\xe1\x7f\x8b\x83\x80\x0e\xe6\x6f\x3b\xb1\x29\x26\x18\xb6\xfd\x1c\x2f\x8b\x27\xff\x88\xe0\xeb"[..];
         let bob_pub = &b"\xde\x9e\xdb\x7d\x7b\x7d\xc1\xb4\xd3\x5b\x61\xc2\xec\xe4\x35\x37\x3f\x83\x43\xc8\x5b\x78\x67\x4d\xad\xfc\x7e\x14\x6f\x88\x2b\x4f"[..];
         let shared = &b"\x4a\x5d\x9d\x5b\xa4\xce\x2d\xe1\x72\x8e\x3b\xf4\x80\x35\x0f\x25\xe0\x7e\x21\xc9\x47\xd1\x9e\x33\x76\xf0\x9b\x3c\x1e\x16\x17\x42"[..];
-        let mut tmp = vec![0u8; 32];
+        let mut tmp = vec![0u8; CURVE25519_SIZE];
 
         assert!(mul_g(&mut tmp, alice_priv).is_ok());
         assert_eq!(tmp, alice_pub);
@@ -99,14 +100,14 @@ mod tests {
         let sk1 = private_key(&mut rng);
         let sk2 = private_key(&mut rng);
 
-        let mut pk1 = vec![0u8; 32];
-        let mut pk2 = vec![0u8; 32];
+        let mut pk1 = vec![0u8; CURVE25519_SIZE];
+        let mut pk2 = vec![0u8; CURVE25519_SIZE];
 
         assert!(mul_g(&mut pk1[..], &sk1[..]).is_ok());
         assert!(mul_g(&mut pk2[..], &sk2[..]).is_ok());
 
-        let mut sh1 = vec![0u8; 32];
-        let mut sh2 = vec![0u8; 32];
+        let mut sh1 = vec![0u8; CURVE25519_SIZE];
+        let mut sh2 = vec![0u8; CURVE25519_SIZE];
 
         assert!(mul(&mut sh1[..], &sk1[..], &pk2[..]).is_ok());
         assert!(mul(&mut sh2[..], &sk2[..], &pk1[..]).is_ok());
