@@ -66,7 +66,7 @@ impl Hash for Sha224 {
         }
     }
 
-    fn box_clone(&self) -> Box<Hash> {
+    fn box_clone(&self) -> Box<dyn Hash> {
         Box::new(self.clone())
     }
 }
