@@ -65,7 +65,7 @@ impl Hash for Sha256 {
         }
     }
 
-    fn box_clone(&self) -> Box<Hash> {
+    fn box_clone(&self) -> Box<dyn Hash> {
         Box::new(self.clone())
     }
 }
